# Asynchronous SOMA Connect library

<!-- markdownlint-disable MD033 -->
<p align="center">
  <a href="https://github.com/Djelibeybi/aiosoma/actions?query=workflow%3ACI">
    <img src="https://img.shields.io/github/actions/workflow/status/Djelibeybi/aiosoma/ci.yml?branch=main&logo=github&style=flat-square" alt="CI status" />
  </a>
  <a href="https://aiosoma.readthedocs.io">
    <img src="https://img.shields.io/readthedocs/aiosoma.svg?logo=read-the-docs&logoColor=fff&style=flat-square" alt="Documentation Status">
  </a>
  <a href="https://codecov.io/gh/Djelibeybi/aiosoma">
    <img src="https://img.shields.io/codecov/c/github/Djelibeybi/aiosoma.svg?logo=codecov&logoColor=fff&style=flat-square" alt="Test coverage percentage">
  </a>
</p>
<p align="center">
  <a href="https://python-poetry.org/">
    <img src="https://img.shields.io/badge/packaging-poetry-299bd7?style=flat-square&logo=data:image/png;base64, " alt="Poetry">
  </a>
  <a href="https://github.com/ambv/black">
    <img src="https://img.shields.io/badge/code%20style-black-000000.svg?style=flat-square" alt="black">
  </a>
  <a href="https://github.com/pre-commit/pre-commit">
    <img src="https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white&style=flat-square" alt="pre-commit">
  </a>
</p>
<p align="center">
  <a href="https://pypi.org/project/aiosoma/">
    <img src="https://img.shields.io/pypi/v/aiosoma.svg?logo=python&logoColor=fff&style=flat-square" alt="PyPI Version">
  </a>
  <img src="https://img.shields.io/pypi/pyversions/aiosoma.svg?style=flat-square&logo=python&amp;logoColor=fff" alt="Supported Python versions">
  <img src="https://img.shields.io/pypi/l/aiosoma.svg?style=flat-square" alt="License">
</p>

Asyncio library that controls SOMA Shades via a SOMA Connect device.

## Installation

Install this via pip (or your favourite package manager):

`pip install aiosoma`

Review [the documentation](https://aiosoma.readthedocs.io) for usage.

## Contributors ✨

Thanks goes to these wonderful people ([emoji key](https://allcontributors.org/docs/en/emoji-key)):

<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
<!-- prettier-ignore-start -->
<!-- markdownlint-disable -->
<table>
  <tbody>
    <tr>
      <td align="center"><a href="https://omg.dje.li"><img src="https://avatars.githubusercontent.com/u/103232?v=4?s=80" width="80px;" alt="Avi Miller"/><br /><sub><b>Avi Miller</b></sub></a><br /><a href="https://github.com/Djelibeybi/aiosoma/commits?author=Djelibeybi" title="Code">💻</a> <a href="https://github.com/Djelibeybi/aiosoma/commits?author=Djelibeybi" title="Documentation">📖</a> <a href="#maintenance-Djelibeybi" title="Maintenance">🚧</a> <a href="https://github.com/Djelibeybi/aiosoma/commits?author=Djelibeybi" title="Tests">⚠️</a></td>
    </tr>
  </tbody>
</table>

<!-- markdownlint-restore -->
<!-- prettier-ignore-end -->

<!-- ALL-CONTRIBUTORS-LIST:END -->

This project follows the [all-contributors](https://github.com/all-contributors/all-contributors) specification. Contributions of any kind welcome!

## Credits

This package was created with [Copier](https://copier.readthedocs.io/) and the
[browniebroke/pypackage-template](https://github.com/browniebroke/pypackage-template)
project template.
